@@ -1236,11 +1236,11 @@ class Project(BaseProject):
         
         Example:
 
-            .. image:: Performances-For-All-Models.png
+            .. image:: ./Performances-For-All-Models.png
             :width: 400
             :alt: Performance plot of all models
 
-            .. image:: Performances-For-All-Models_boxplot.png
+            .. image:: ./Performances-For-All-Models_boxplot.png
             :width: 400
             :alt: Performance plot (box plot) of all models
 
